@@ -57,6 +57,8 @@ nsThebesFontMetrics::nsThebesFontMetrics()
 
 nsThebesFontMetrics::~nsThebesFontMetrics()
 {
+    if (mDeviceContext)
+        mDeviceContext->FontMetricsDeleted(this);
     delete mFontStyle;
     //delete mFontGroup;
 }
@@ -94,6 +96,7 @@ nsThebesFontMetrics::Init(const nsFont& aFont, nsIAtom* aLangGroup,
 NS_IMETHODIMP
 nsThebesFontMetrics::Destroy()
 {
+    mDeviceContext = nsnull;
     return NS_OK;
 }
 
